import { DeclarationReflection, LiteralType, ReflectionFlags, ReflectionKind, ReflectionType, SomeType, TupleType, TypeOperatorType } from 'typedoc';
import { AllowedHttpMethod } from '../model';
import { NAME_BUILTIN_COMMAND_MODULE, NAME_EXECUTE_METHOD_MAP, NAME_METHOD_MAP, NAME_NEW_METHOD_MAP, NAME_PARAMS } from './converter';
/**
 * Type corresponding to a reflection of a {@linkcode @appium/types#MethodMap}
 */
export declare type MethodMapDeclarationReflection = DeclarationReflectionWithReflectedType & {
    name: typeof NAME_METHOD_MAP | typeof NAME_NEW_METHOD_MAP;
};
/**
 * Type corresponding to a reflection of {@linkcode @appium/base-driver}
 */
export declare type BaseDriverDeclarationReflection = DeclarationReflection & {
    name: typeof NAME_BUILTIN_COMMAND_MODULE;
    kind: ReflectionKind.Module;
};
/**
 * Utility to narrow a declaration reflection to a specific `SomeType`
 */
declare type WithSomeType<T extends SomeType, R extends DeclarationReflection = DeclarationReflection> = R & {
    type: T;
};
/**
 * Utility; a TupleType with literal elements
 */
declare type TupleTypeWithLiteralElements = TupleType & {
    elements: LiteralType[];
};
/**
 * Type for the parameters of a command definition or execute method definition.
 *
 * Node that merging `TypeOperatorType` won't work because it will no longer satisfy `SomeType`, because `SomeType` is a finite collection.
 */
export declare type MethodDefParamNamesDeclarationReflection = WithSomeType<TypeOperatorType & {
    operator: 'readonly';
    target: TupleTypeWithLiteralElements;
}>;
/**
 * Narrows a declaration reflection to one having a reflection type and a property kind. Generic
 */
export declare type PropDeclarationReflection = DeclarationReflectionWithReflectedType & {
    kind: ReflectionKind.Property;
};
/**
 * A type corresponding to the HTTP method of a route, which is a property off of the object with the route name in a `MethodMap`
 */
export declare type HTTPMethodDeclarationReflection = PropDeclarationReflection & {
    originalName: AllowedHttpMethod;
};
/**
 * A declaration reflection having a reflection type. Generic
 */
export declare type DeclarationReflectionWithReflectedType = WithSomeType<ReflectionType>;
/**
 * Type corresponding to the value of the `command` property within a `MethodDef`, which must be a type literal.
 */
export declare type CommandPropDeclarationReflection = WithSomeType<LiteralType>;
/**
 * A generic type guard
 */
export declare type Guard<T> = (value: any) => value is T;
/**
 * Type corresponding to an execute method map
 */
export declare type ExecMethodDeclarationReflection = DeclarationReflectionWithReflectedType & {
    name: typeof NAME_EXECUTE_METHOD_MAP;
    flags: ReflectionFlags & {
        isStatic: true;
    };
};
/**
 * Type corresponding to the `params` prop of a `MethodDef`
 */
export declare type MethodDefParamsPropDeclarationReflection = DeclarationReflectionWithReflectedType & {
    name: typeof NAME_PARAMS;
};
/**
 * Type corresponding to the `payloadParams` prop of an `ExecMethodDef`
 */
export declare type ExecMethodDefParamsPropDeclarationReflection = DeclarationReflectionWithReflectedType & {
    name: typeof NAME_PARAMS;
};
export {};
//# sourceMappingURL=types.d.ts.map