/**
 * A bunch of type guards. Because here is a place to put all of them.
 * @module
 */
import { DeclarationReflection, ReflectionType, TypeOperatorType, TupleType, LiteralType } from 'typedoc';
import { BaseDriverDeclarationReflection, CommandPropDeclarationReflection, DeclarationReflectionWithReflectedType, ExecMethodDeclarationReflection, HTTPMethodDeclarationReflection, MethodDefParamNamesDeclarationReflection, MethodMapDeclarationReflection, MethodDefParamsPropDeclarationReflection, PropDeclarationReflection, ExecMethodDefParamsPropDeclarationReflection } from './converter/types';
import { AllowedHttpMethod, ExecMethodData } from './model';
/**
 * Type guard for {@linkcode DeclarationReflection}
 * @param value any value
 */
export declare function isDeclarationReflection(value: any): value is DeclarationReflection;
/**
 * Type guard for {@linkcode ReflectionType}
 * @param value any value
 */
export declare function isReflectionType(value: any): value is ReflectionType;
/**
 * Type guard for {@linkcode TypeOperatorType}
 * @param value any value
 */
export declare function isTypeOperatorType(value: any): value is TypeOperatorType;
/**
 * Type guard for {@linkcode LiteralType}
 * @param value any value
 */
export declare function isLiteralType(value: any): value is LiteralType;
/**
 * Type guard for {@linkcode TupleType}
 * @param value any value
 */
export declare function isTupleType(value: any): value is TupleType;
/**
 * Type guard for a {@linkcode DeclarationReflectionWithReflectedType} corresponding to
 * the `executeMethodMap` static property of an extension class.
 * @param value any
 */
export declare function isExecMethodDefReflection(value: any): value is ExecMethodDeclarationReflection;
/**
 * Type guard for a {@linkcode MethodDefParamNamesDeclarationReflection} corresponding to a list of required or optional parameters within a command or execute method definition.
 * @param value any value
 */
export declare function isMethodDefParamNamesDeclarationReflection(value: any): value is MethodDefParamNamesDeclarationReflection;
/**
 * Type guard for a {@linkcode PropDeclarationReflection} corresponding to some property of a constant object.
 * @param value any value
 */
export declare function isRoutePropDeclarationReflection(value: any): value is PropDeclarationReflection;
/**
 * Type guard for a {@linkcode BaseDriverDeclarationReflection} corresponding to the `@appium/base-driver` module (_not_ the class).
 * @param value any value
 */
export declare function isBaseDriverDeclarationReflection(value: any): value is BaseDriverDeclarationReflection;
/**
 * Type guard for a property of an object (a {@linkcode Reflection} having kind {@linkcode ReflectionKind.Property}).
 * @param value any value
 * @returns
 */
export declare function isPropertyKind(value: any): boolean;
/**
 * Type guard for a {@linkcode MethodMapDeclarationReflection} corresponding to the `newMethodMap` static property of an extension class _or_ the `METHOD_MAP` export within `@appium/base-driver`.
 *
 * Note that the type does not care about the `isStatic` flag, but this guard does.
 * @param value any value
 */
export declare function isMethodMapDeclarationReflection(value: any): value is MethodMapDeclarationReflection;
/**
 * Type guard for a {@linkcode DeclarationReflectionWithReflectedType} a declaration reflection having a reflection type.
 *
 * I don't know what that means, exactly, but there it is.
 * @param value any value
 */
export declare function isReflectionWithReflectedType(value: any): value is DeclarationReflectionWithReflectedType;
export declare function isHTTPMethodDeclarationReflection(value: any): value is HTTPMethodDeclarationReflection;
/**
 * Type guard for an {@linkcode AllowedHttpMethod}
 *
 * @param value any value
 */
export declare function isAllowedHTTPMethod(value: any): value is AllowedHttpMethod;
/**
 * Type guard for a {@linkcode CommandPropDeclarationReflection} corresponding to the `command` property of a {@linkcode @appium/types#MethodDef} object contained within a {@linkcode @appium/types#MethodMap}.
 * @param value any value
 */
export declare function isCommandPropDeclarationReflection(value: any): value is CommandPropDeclarationReflection;
/**
 * Type guard for a {@linkcode ExecMethodData} derived from a {@linkcode @appium/types#ExecuteMethodMap} object.
 * @param value any value
 */
export declare function isExecMethodData(value: any): value is ExecMethodData;
/**
 * Type guard for a {@linkcode MethodDefParamsPropDeclarationReflection} corresponding to the `params` prop of a `MethodDef`
 * @param value any value
 */
export declare function isMethodDefParamsPropDeclarationReflection(value: any): value is MethodDefParamsPropDeclarationReflection;
/**
 * Type guard for a {@linkcode ExecMethodDefParamsPropDeclarationReflection} corresponding to the `payloadParams` prop of an `ExecuteMethodDef`.
 * @param value any value
 */
export declare function isExecMethodDefParamsPropDeclarationReflection(value: any): value is ExecMethodDefParamsPropDeclarationReflection;
//# sourceMappingURL=guards.d.ts.map