"use strict";
/**
 * Declares new "kinds" within TypeDoc.
 *
 * A "kind" is a way for TypeDoc to understand how to document something.  Mostly, these have a 1:1 relationship with some sort of TypeScript concept.  This is unsuitable for our purposes, since there's no notion of a "command" or "execute method" in TypeScript.  To that end, we must create new ones.
 *
 * Note that _creating new `ReflectionKind`s is a hack_ and is not supported by TypeDoc. This is the reason you will see `as any` wherever a {@linkcode AppiumPluginReflectionKind} is used.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppiumPluginReflectionKind = exports.NS = void 0;
const utils_1 = require("./utils");
/**
 * Namespace for our reflection kinds.
 *
 * The only reason we use a namespace is to avoid conflicts with TypeDoc or other plugins monkeying around in the "kind" system.
 */
exports.NS = 'appium';
/**
 * Extends the TypeDoc's `ReflectionKind` to add namespaced kinds
 */
var AppiumPluginReflectionKind;
(function (AppiumPluginReflectionKind) {
    AppiumPluginReflectionKind[AppiumPluginReflectionKind["COMMANDS"] = (0, utils_1.addReflectionKind)(exports.NS, 'Commands')] = "COMMANDS";
    AppiumPluginReflectionKind[AppiumPluginReflectionKind["COMMAND"] = (0, utils_1.addReflectionKind)(exports.NS, 'Command')] = "COMMAND";
    AppiumPluginReflectionKind[AppiumPluginReflectionKind["EXECUTE_METHOD"] = (0, utils_1.addReflectionKind)(exports.NS, 'ExecuteMethod')] = "EXECUTE_METHOD";
    AppiumPluginReflectionKind[AppiumPluginReflectionKind["ANY"] = (0, utils_1.addReflectionKind)(exports.NS, 'Any', AppiumPluginReflectionKind.COMMAND | AppiumPluginReflectionKind.EXECUTE_METHOD | AppiumPluginReflectionKind.COMMANDS)] = "ANY";
})(AppiumPluginReflectionKind = exports.AppiumPluginReflectionKind || (exports.AppiumPluginReflectionKind = {}));
//# sourceMappingURL=kind.js.map