import { ContainerReflection, PageEvent, ReflectionKind, Renderer } from 'typedoc';
import { MarkdownTheme } from 'typedoc-plugin-markdown';
/**
 * Name of the theme; used at definition time
 */
export declare const THEME_NAME = "appium";
export declare class AppiumTheme extends MarkdownTheme {
    #private;
    /**
     * Creates template renderers and registers all {@linkcode Handlebars} helpers.
     * @param renderer - TypeDoc renderer
     *
     * @todo Make `hideBreadcrumbs` configurable
     */
    constructor(renderer: Renderer);
    /**
     * This is essentially a lookup of {@linkcode ReflectionKind}s to templates.  It also controls in which directory the output files live.
     *
     * If `isLeaf` is `false`, the model gets its own document.
     */
    get mappings(): TemplateMapping[];
}
/**
 * A function which accepts {@linkcode PageEvent} as its model and returns the final markdown.
 */
export declare type TemplateRenderer = (pageEvent: PageEvent<ContainerReflection>) => string;
/**
 * A mapping of {@linkcode ReflectionKind} to a template and other metadata.
 *
 * Defined by {@linkcode MarkdownTheme}.
 * @public
 */
export declare type TemplateMapping = {
    kind: ReflectionKind[];
    isLeaf: boolean;
    directory: string;
    template: (pageEvent: PageEvent<ContainerReflection>) => string;
};
//# sourceMappingURL=index.d.ts.map